Skip to contents

Annual Consumer Price Index data sourced from Federal Reserve Economic Data (FRED) for price level and inflation adjustments across survey years.

Usage

cpi_series

Format

A tbl_df tibble data frame with 2 variables:

year

4-digit year (integer)

cpi

Annual CPI index value (numeric)

Federal Reserve Bank of St. Louis (FRED) API.