Consumer Price Index (CPI) Series
cpi_series.RdAnnual Consumer Price Index data sourced from Federal Reserve Economic Data (FRED) for price level and inflation adjustments across survey years.
cpi_series.RdAnnual Consumer Price Index data sourced from Federal Reserve Economic Data (FRED) for price level and inflation adjustments across survey years.